@@ -6,6 +6,6 @@ logger.setLevel(logging.INFO)
 formatter = logging.Formatter('%(levelname)s: %(message)s')
 
 ch = logging.StreamHandler(stream=sys.stdout)
-ch.setLevel(logging.INFO)
+ch.setLevel(logging.DEBUG)
 ch.setFormatter(formatter)
 logger.addHandler(ch)
\ No newline at end of file
